@@ -65,6 +65,7 @@ TILEDB_KWARG_DEFAULTS = {
     'date_spec': None,
     'cell_order': 'row-major',
     'tile_order': 'row-major',
+    'timestamp': None,
     'debug': None,
 }
 
@@ -232,7 +233,12 @@ def dim_for_column(ctx, name, dim_info, col, tile=None, full_domain=False,
                 date_unit = np.datetime_data(dtype)[0]
                 dim_min = np.datetime64(dtype_min + 1, date_unit)
                 tile_max = np.iinfo(np.uint64).max - tile
-                if np.abs(np.uint64(dtype_max) - np.uint64(dtype_min)) > tile_max:
+
+                # modular arithmetic gives misleading overflow warning.
+                with np.errstate(over="ignore"):
+                    dtype_range = np.uint64(dtype_max) - np.uint64(dtype_min)
+
+                if np.abs(dtype_range) > tile_max:
                     dim_max = np.datetime64(dtype_max - tile, date_unit)
             elif dtype is np.int64:
                 dim_min = dtype_min + 1
@@ -574,8 +580,10 @@ def from_pandas(uri, dataframe, **kwargs):
         if tiledb_args.get('debug', True):
             print("`tiledb.read_pandas` writing '{}' rows".format(len(dataframe)))
 
+        timestamp = tiledb_args.get('timestamp', None)
+
         try:
-            A = tiledb.open(uri, 'w', ctx=ctx)
+            A = tiledb.open(uri, 'w', timestamp=timestamp, ctx=ctx)
 
             if A.schema.sparse:
                 coords = []
@@ -735,7 +743,9 @@ def from_csv(uri, csv_file, **kwargs):
             * ``sparse``: (default True) Create sparse schema
             * ``tile``: Dimension tiling: accepts either Int or a list of Tuple[Int] with per-dimension
               'tile' arguments to apply to the generated ArraySchema.
-            * ``capacity``: Schema capacity
+            * ``capacity``: Schema capacity.
+            * ``timestamp``: Write TileDB array at specific timestamp.
+            * ``row_start_idx``: Start index to start new write (for row-indexed ingestions).
             * ``date_spec``: Dictionary of {``column_name``: format_spec} to apply to date/time
               columns which are not correctly inferred by pandas 'parse_dates'.
               Format must be specified using the Python format codes:
